raft

package
v0.0.0-...-1334a7b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2023 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	RaftServer_SendMessage_FullMethodName = "/vanus.core.raft.RaftServer/SendMessage"
)

Variables

var File_vanus_core_raft_raft_proto protoreflect.FileDescriptor
var RaftServer_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "vanus.core.raft.RaftServer",
	HandlerType: (*RaftServerServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "SendMessage",
			Handler:       _RaftServer_SendMessage_Handler,
			ClientStreams: true,
		},
	},
	Metadata: "vanus/core/raft/raft.proto",
}

RaftServer_ServiceDesc is the grpc.ServiceDesc for RaftServer service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterRaftServerServer

func RegisterRaftServerServer(s grpc.ServiceRegistrar, srv RaftServerServer)

Types

type RaftServerClient

type RaftServerClient interface {
	SendMessage(ctx context.Context, opts ...grpc.CallOption) (RaftServer_SendMessageClient, error)
}

RaftServerClient is the client API for RaftServer service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewRaftServerClient

func NewRaftServerClient(cc grpc.ClientConnInterface) RaftServerClient

type RaftServerServer

type RaftServerServer interface {
	SendMessage(RaftServer_SendMessageServer) error
}

RaftServerServer is the server API for RaftServer service. All implementations should embed UnimplementedRaftServerServer for forward compatibility

type RaftServer_SendMessageClient

type RaftServer_SendMessageClient interface {
	Send(*raftpb.Message) error
	CloseAndRecv() (*emptypb.Empty, error)
	grpc.ClientStream
}

type RaftServer_SendMessageServer

type RaftServer_SendMessageServer interface {
	SendAndClose(*emptypb.Empty) error
	Recv() (*raftpb.Message, error)
	grpc.ServerStream
}

type UnimplementedRaftServerServer

type UnimplementedRaftServerServer struct {
}

UnimplementedRaftServerServer should be embedded to have forward compatible implementations.

func (UnimplementedRaftServerServer) SendMessage

type UnsafeRaftServerServer

type UnsafeRaftServerServer interface {
	// contains filtered or unexported methods
}

UnsafeRaftServerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RaftServerServer will result in compilation errors.

Jump to